@@ -8,9 +8,9 @@ from ._src.interval import Interval
 def _fmean(x: float, y: float) -> float:
     assert x <= y
     if x <= 0 <= y:
-        return 0.5 * (interval.maximum + interval.minimum)
+        return 0.5 * (x + y)
     else:
-        return interval.minimum + 0.5 * (interval.maximum - interval.minimum)
+        return x + 0.5 * (y - x)
 
 def _imean(interval: Interval) -> float:
     return _fmean(*interval._endpoints)
@@ -72,11 +72,16 @@ def partition(
             if nextafter(*p) == p[1]:
                 extremes[k] = partitions.pop(k)
                 continue
-            for _ in range(round((v / 2).size / (split_size / 2)).bit_length() // 2 + 1):
-                p.extend(_fmean(p[i - 1], p[i]) for i in range(1, len(p)))
-                p.sort()
+            elif isinf(p[0]) or isinf(p[1]):
+                left, right = _split(k)
+                p = [*left._endpoints, right.maximum]
+            else:
+                for _ in range(1 + round((v / 2).size / (split_size / 2)).bit_length() // 2):
+                    p.extend(_fmean(p[i - 1], p[i]) for i in range(1, len(p)))
+                    p.sort()
+            del partitions[k]
             for i in range(1, len(p)):
-                k = interval[p[i - 1] : p[i]]
+                k = Interval((p[i - 1], p[i]))
                 v = partitions[k] = integral(k)
                 if v.size > split_size:
                     split_partitions[k] = v
